==> ejc-bid-impl-3.0.0-20220323.110522-179-sources.jar: com/ejianc/business/bid/bean/ChoosePersonEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.bid.bean.ChoosePersonZiEntity;
/**
 * 中标人员选择
 * 
 * @author generator
 * 
 */
 @TableName("t_bid_choose_person")
public class ChoosePersonEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="xm_id")
    private Long xmId; // 项目id
    @TableField(value="xm")
    private String xm; // 项目
    @TableField(value="sqrq")
    private Date sqrq; // 申请日期
    @TableField(value="bill_date")
    private Date billDate; // 编制日期
    
    @TableField(exist=false)
    @SubEntity(serviceName="choosePersonZiService",pidName = "pid")
    private List<ChoosePersonZiEntity> choosePersonZiList = new ArrayList<>(); // 中标人员选择子实体
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getXmId() {
        return xmId;
    }

    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }
    public Date getSqrq() {
        return sqrq;
    }

    public void setSqrq(Date sqrq) {
        this.sqrq = sqrq;
    }

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public List<ChoosePersonZiEntity> getChoosePersonZiList() {
        return choosePersonZiList;
    }

    public void setChoosePersonZiList(List<ChoosePersonZiEntity> choosePersonZiList) {
        this.choosePersonZiList = choosePersonZiList;
    }
}

==> ejc-bid-impl-3.0.0-20221208.083005-294-sources.jar: com/ejianc/business/bid/bean/ChoosePersonEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.bid.bean.ChoosePersonZiEntity;
/**
 * 中标人员选择
 * 
 * @author generator
 * 
 */
 @TableName("t_bid_choose_person")
public class ChoosePersonEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="xm_id")
    private Long xmId; // 项目id
    @TableField(value="xm")
    private String xm; // 项目
    @TableField(value="sqrq")
    private Date sqrq; // 申请日期
    @TableField(value="bill_date")
    private Date billDate; // 编制日期

    @TableField(value="xmlx_id")
    private Long xmlxId; // 项目立项id
    @TableField(value="xmlx_name")
    private String xmlxName; // 项目立项名称
    @TableField(value="xmjl_id")
    private Long xmjlId; // 项目经理id
    @TableField(value="xmjl")
    private String xmjl; // 项目经理
    @TableField(value="sfgs")
    private Integer sfgs; // 是否公示（0：否，1：是）


    public Long getXmjlId() {
        return xmjlId;
    }

    public void setXmjlId(Long xmjlId) {
        this.xmjlId = xmjlId;
    }

    public String getXmjl() {
        return xmjl;
    }

    public void setXmjl(String xmjl) {
        this.xmjl = xmjl;
    }

    public Integer getSfgs() {
        return sfgs;
    }

    public void setSfgs(Integer sfgs) {
        this.sfgs = sfgs;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="choosePersonZiService",pidName = "pid")
    private List<ChoosePersonZiEntity> choosePersonZiList = new ArrayList<>(); // 中标人员选择子实体
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getXmId() {
        return xmId;
    }

    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }
    public Date getSqrq() {
        return sqrq;
    }

    public void setSqrq(Date sqrq) {
        this.sqrq = sqrq;
    }

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public List<ChoosePersonZiEntity> getChoosePersonZiList() {
        return choosePersonZiList;
    }

    public void setChoosePersonZiList(List<ChoosePersonZiEntity> choosePersonZiList) {
        this.choosePersonZiList = choosePersonZiList;
    }

    public Long getXmlxId() {
        return xmlxId;
    }

    public void setXmlxId(Long xmlxId) {
        this.xmlxId = xmlxId;
    }

    public String getXmlxName() {
        return xmlxName;
    }

    public void setXmlxName(String xmlxName) {
        this.xmlxName = xmlxName;
    }
}
